@@ -2,19 +2,16 @@ package Alien::Base::ModuleBuild::Repository::HTTP;
 
 use strict;
 use warnings;
-
-our $VERSION = '1.08';
-
 use Carp;
-
 use HTTP::Tiny;
 use Scalar::Util qw( blessed );
 use URI;
-
 use Alien::Base::ModuleBuild::Utils;
-
 use parent 'Alien::Base::ModuleBuild::Repository';
 
+# ABSTRACT: HTTP repository handler
+our $VERSION = '1.15'; # VERSION
+
 our $Has_HTML_Parser = eval { require HTML::LinkExtor; 1 };
 
 sub connection {
@@ -164,7 +161,7 @@ sub check_http_response {
       my $reason = $res->{status} == 599 ? $res->{content} : "@{[ $res->{status} ]} @{[ $res->{reason} ]}";
       if($res->{status} == 599 && $reason =~ /https support/)
       {
-        $reason .= "See https://github.com/Perl5-Alien/Alien-Base-ModuleBuild/issues/6#issuecomment-417097485";
+        $reason .= "See https://github.com/PerlAlien/Alien-Base-ModuleBuild/issues/6#issuecomment-417097485";
       }
       return ( 1, $reason, $res->{headers}, $res->{url} );
     }
@@ -174,3 +171,65 @@ sub check_http_response {
 
 1;
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Alien::Base::ModuleBuild::Repository::HTTP - HTTP repository handler
+
+=head1 VERSION
+
+version 1.15
+
+=head1 AUTHOR
+
+Original author: Joel A Berger E<lt>joel.a.berger@gmail.comE<gt>
+
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+Contributors:
+
+David Mertens (run4flat)
+
+Mark Nunberg (mordy, mnunberg)
+
+Christian Walde (Mithaldu)
+
+Brian Wightman (MidLifeXis)
+
+Graham Ollis (plicease)
+
+Zaki Mughal (zmughal)
+
+mohawk2
+
+Vikas N Kumar (vikasnkumar)
+
+Flavio Poletti (polettix)
+
+Salvador Fandiño (salva)
+
+Gianni Ceccarelli (dakkar)
+
+Pavel Shaydo (zwon, trinitum)
+
+Kang-min Liu (劉康民, gugod)
+
+Nicholas Shipp (nshp)
+
+Petr Pisar (ppisar)
+
+Alberto Simões (ambs)
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012-2020 by Joel A Berger.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
